/** @file
 * @brief SerializeServiceContainer class header. This class holds Service objects in a list for serialization.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef SERIALIZESERVICECONTAINER_H
#define SERIALIZESERVICECONTAINER_H

#include "service.h"
#include "logger.h"

#include <boost/serialization/list.hpp>
#include <boost/serialization/vector.hpp>
#include <boost/serialization/shared_ptr.hpp>
#include <boost/serialization/export.hpp>

#include <boost/shared_ptr.hpp>
#include <list>

#include "service_dhs.h"
#include "service_ods.h"
#include "service_dyndns.h"
#include "service_dyns.h"
#include "service_easydns.h"
#include "service_tzo.h"
#include "service_zoneedit.h"
#include "service_gnudip.h"


class SerializeServiceContainer
{

private:

    std::list<Service::Ptr> ContainingServices;

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & ar, const unsigned int version)
    {
        ar & ContainingServices;
    }

public:

    typedef boost::shared_ptr<SerializeServiceContainer> Ptr;

    SerializeServiceContainer();

    ~SerializeServiceContainer();

    void add_service(Service::Ptr service);

    std::list<Service::Ptr> get_containing_services() const;

};

#endif
